@@ -8,12 +8,12 @@ from __future__ import absolute_import
 
 from .abstract_comm import AbstractCommunicator
 
+from .file_communicator import FileCommunicator
+from .gpib_communicator import GPIBCommunicator
+from .loopback_communicator import LoopbackCommunicator
+from .serial_communicator import SerialCommunicator
 from .socket_communicator import SocketCommunicator
 from .usb_communicator import USBCommunicator
-from .serial_communicator import SerialCommunicator
-from .visa_communicator import VisaCommunicator
-from .loopback_communicator import LoopbackCommunicator
-from .gi_gpib_communicator import GPIBCommunicator
-from .file_communicator import FileCommunicator
 from .usbtmc_communicator import USBTMCCommunicator
+from .visa_communicator import VisaCommunicator
 from .vxi11_communicator import VXI11Communicator
